@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import json
 import re
 from functools import partial
 from pathlib import Path
@@ -16,13 +15,13 @@ from typing import (
     Tuple,
     Type,
     TypeVar,
-    cast,
     get_type_hints,
 )
 
 import attr
 
-from .utils.formats import format_json, to_unix
+from .config import Config
+from .utils.formats import format_json, parse_json, to_unix
 
 T = TypeVar("T")
 
@@ -41,18 +40,20 @@ def verify_name(name: str) -> None:
 @attr.s(auto_attribs=True)
 class JsonFile:
     _file: Path
+    _config: Config
 
     def write_json(self, data: Dict[Any, Any]) -> None:
         if data is not None:
-            self._file.write_text(format_json(data), encoding="utf-8")
+            self._file.write_text(
+                format_json(data, config=self._config), encoding="utf-8"
+            )
         elif self._file.exists():
             self._file.unlink()
 
     def read_json(self) -> Optional[Dict[Any, Any]]:
         if self._file.is_file():
-            return cast(
-                Dict[Any, Any], json.loads(self._file.read_text(encoding="utf-8"))
-            )
+            return parse_json(self._file.read_text(encoding="utf-8"))
+
         else:
             return None
 
@@ -60,6 +61,7 @@ class JsonFile:
 @attr.s(auto_attribs=True)
 class TextFile:
     _file: Path
+    _config: Config
 
     def write_text(self, data: str) -> None:
         if data:
@@ -74,13 +76,16 @@ class TextFile:
             return ""
 
 
-@attr.s(auto_attribs=True)
+@attr.s(auto_attribs=True, init=False)
 class ScriptFile:
     """
     File that TTS strips trailing new-lines from when sending to external editor
     """
 
-    _file: TextFile = attr.ib(converter=TextFile)
+    _file: TextFile
+
+    def __init__(self, path: Path, config: Config):
+        self._file = TextFile(path, config)
 
     def write_text(self, data: str) -> None:
         self._file.write_text(data)
@@ -95,16 +100,17 @@ class ScriptFile:
 @attr.s(auto_attribs=True)
 class UnpackedIndex(Generic[T]):
     _path: Path
-    _child_type: Callable[[Path], T]
+    _config: Config
+    _child_type: Callable[[Path, Config], T]
 
     def __class_getitem__(
         cls, child_type: Type[T]
-    ) -> Callable[[Path], UnpackedIndex[T]]:
+    ) -> Callable[[Path, Config], UnpackedIndex[T]]:
         return partial(cls, child_type=child_type)
 
     @property
     def _index(self) -> TextFile:
-        return TextFile(self._path.joinpath("index.list"))
+        return TextFile(self._path.joinpath("index.list"), self._config)
 
     def exists(self) -> bool:
         return self._path.is_dir()
@@ -118,7 +124,7 @@ class UnpackedIndex(Generic[T]):
             path.mkdir(parents=True, exist_ok=True)
         elif not path.is_dir():
             raise Exception("Objects must be directories")
-        return self._child_type(path)
+        return self._child_type(path, self._config)
 
     def children(self) -> Iterator[Tuple[str, T]]:
         if not self.exists():
@@ -141,11 +147,13 @@ class UnpackedIndex(Generic[T]):
 
 
 def _get_child(self: Any, *, path: Path, make: Callable[..., T]) -> T:
-    return make(self._path.joinpath(path))
+    return make(self._path.joinpath(path), self._config)
 
 
 def _unpacked_layout(cls: type) -> type:
-    new_cls = attr.make_class(cls.__name__, {"_path": attr.ib(type=Path)})
+    new_cls = attr.make_class(
+        cls.__name__, {"_path": attr.ib(type=Path), "_config": attr.ib(type=Config)}
+    )
     hints = get_type_hints(cls, None, {cls.__name__: new_cls})
     for name, attr_type in hints.items():
         p = partial(_get_child, path=getattr(cls, name), make=attr_type)
